<?php
namespace AIOSEO\Plugin\Addon\IndexNow\Options;

use AIOSEO\Plugin\Common\Traits;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Handles all options.
 *
 * @since 1.0.0
 */
class Options {
	use Traits\Options;

	/**
	 * All the default options.
	 *
	 * @since 1.0.0
	 *
	 * @var array
	 */
	protected $defaults = [
		// phpcs:disable WordPress.Arrays.ArrayDeclarationSpacing
		'indexNow' => [
			'apiKey' => [ 'type' => 'string' ]
		]
		// phpcs:disable WordPress.Arrays.ArrayDeclarationSpacing
	];

	/**
	 * Class constructor.
	 *
	 * @since 1.0.0
	 *
	 * @param string $optionsName The options name.
	 */
	public function __construct( $optionsName = 'aioseo_index_now_options' ) {
		$this->optionsName = is_network_admin() ? $optionsName . '_network' : $optionsName;

		$this->init();

		add_action( 'shutdown', [ $this, 'save' ] );
	}

	/**
	 * Initializes the options.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	protected function init() {
		$options = $this->getIndexNowDbOptions();
		aioseo()->core->optionsCache->setOptions( $this->optionsName, apply_filters( 'aioseo_get_index_now_options', $options ) );
	}

	/**
	 * Returns the DB options.
	 *
	 * @since 1.0.0
	 *
	 * @return array The options.
	 */
	public function getIndexNowDbOptions() {
		$dbOptions = $this->getDbOptions( $this->optionsName );
		if ( empty( $dbOptions['indexNow']['apiKey'] ) ) {
			$dbOptions['indexNow']['apiKey'] = aioseoIndexNow()->helpers->generateApiKey();
			update_option( $this->optionsName, wp_json_encode( $dbOptions ) );
		}

		$this->defaultsMerged = array_replace_recursive( $this->defaults, $this->defaultsMerged );

		return array_replace_recursive(
			$this->defaultsMerged,
			$this->addValueToValuesArray( $this->defaultsMerged, $dbOptions )
		);
	}

	/**
	 * Sanitizes, then saves the options to the database.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $newoptions The new options to sanitize, then save.
	 * @return void
	 */
	public function sanitizeAndSave( $newOptions ) {
		$this->init();

		if ( ! is_array( $newOptions ) ) {
			return;
		}

		$cachedOptions = aioseo()->core->optionsCache->getOptions( $this->optionsName );
		$dbOptions     = array_replace_recursive(
			$cachedOptions,
			$this->addValueToValuesArray( $cachedOptions, $newOptions, [], true )
		);

		aioseo()->core->optionsCache->setOptions( $this->optionsName, $dbOptions );
		$this->save( true );
	}
}